@@ -19,7 +19,7 @@ class Cfg(object):
     TEMPLATE_AUTO_RELOAD = False
     TEMPLATE_LOADER = 'pysi.template.file_loader'
     FLASH_COOKIE_NAME = u'pysi.flash'
-    ROUTING = 'pysi.auto_routing'  # функция или очередь функций роутинга
+    ROUTING_QUEUE = ['pysi.auto_routing']  # очередь функций роутинга
 
     def set_defaults(self, **kwargs):
         '''
