@@ -7,6 +7,8 @@ from util import obj_from_str, cached_function
 
 def render_to_string(rq, template, context=None):
     context = context or {}
+    if not isinstance(context, dict):
+        return unicode(context)
     for k, v in rq.context.iteritems():
         if k not in context:
             context[k] = v
@@ -67,7 +69,7 @@ class FileLoader(object):
                 app_name, path = path.split('/', 1)
                 f = open('%s/templates/%s' % (app_name, path))
             except (IOError, ValueError):
-                assert 0, 'template not found: %s' % fn
+                assert 0, 'template not found: %s' % path
         path = os.path.normpath(os.path.join(os.getcwd(), f.name))
         self.mtimes[path] = os.path.getmtime(path)
         return (f.read().decode('utf-8'), path, 
